@@ -282,7 +282,6 @@ overlay.nma <- function(pred, timebins, method="common", link="identity", lim="c
   checkmate::assertChoice(plottype, choices=c("rel", "pred"), add=argcheck)
   checkmate::reportAssertions(argcheck)
 
-
   # Declare global variable
   cor <- NULL
   dif <- NULL
@@ -316,23 +315,24 @@ overlay.nma <- function(pred, timebins, method="common", link="identity", lim="c
       predref <- 0
     }
 
+    if (skip==FALSE) {
+      nmanet <- network$data.ab[network$data.ab$time>incl.range[1] & network$data.ab$time<=incl.range[2],]
 
-    nmanet <- network$data.ab[network$data.ab$time>incl.range[1] & network$data.ab$time<=incl.range[2],]
+      # Take the follow-up closes to mean(incl.range) if multiple fups are within the range
+      nmanet <- nmanet %>% dplyr::group_by(studyID) %>%
+        #dplyr::mutate(dif=time-mean(incl.range)) %>%
+        dplyr::mutate(dif=time-ifelse(plottype=="pred", pred$times[timeindex], mean(incl.range))) %>%
+        dplyr::arrange(dif) %>%
+        dplyr::group_by(studyID, arm) %>%
+        dplyr::slice_head()
 
-    # Take the follow-up closes to mean(incl.range) if multiple fups are within the range
-    nmanet <- nmanet %>% dplyr::group_by(studyID) %>%
-      #dplyr::mutate(dif=time-mean(incl.range)) %>%
-      dplyr::mutate(dif=time-ifelse(plottype=="pred", pred$times[timeindex], mean(incl.range))) %>%
-      dplyr::arrange(dif) %>%
-      dplyr::group_by(studyID, arm) %>%
-      dplyr::slice_head()
+      if (!1 %in% nmanet$treatment) {
+        message(paste(c("overlay.nma not possible between ", str.incl.range,
+                        ". Data for network reference (treatment=1) not available in this time bin"),
+                      collapse = ""))
 
-    if (!1 %in% nmanet$treatment) {
-      message(paste(c("overlay.nma not possible between ", str.incl.range,
-                    ". Data for network reference (treatment=1) not available in this time bin"),
-                    collapse = ""))
-
-      skip <- TRUE
+        skip <- TRUE
+      }
     }
 
     if (skip==FALSE) {
@@ -379,12 +379,6 @@ overlay.nma <- function(pred, timebins, method="common", link="identity", lim="c
       nma <- nma.run(data.ab=nmanet, method=method, link=link,
                      ...)
 
-      # if (any(nma$BUGSoutput$summary[,"Rhat"]>1.02)) {
-      #   warn <- rownames(nma$BUGSoutput$summary)[which(nma$BUGSoutput$summary[,"Rhat"]>1.02)]
-      #   warning(crayon::bold(crayon::red(paste0("Rhat values for the following parameters are >1.02 - suggests problems with NMA model convergence:\n",
-      #                                           paste(warn, collapse="\n")))))
-      # }
-
       if (method=="common" | "cred" %in% lim) {
         predtrt <- sample(predref, size=nma$BUGSoutput$n.sims, replace=TRUE) + nma$BUGSoutput$sims.list$d[,-1]
       } else if (method=="random" & "pred" %in% lim) {
@@ -542,7 +536,9 @@ nodesplit.plotdata <- function(nodesplit, type) {
 #' }
 #'
 #' @export
-timeplot <- function(network, level="treatment", plotby="arm", link="identity", ...) {
+timeplot <- function(network, level="treatment",
+                     plotby="arm", link="identity",
+                     ...) {
   # Run checks
   argcheck <- checkmate::makeAssertCollection()
   checkmate::assertClass(network, "mb.network", add=argcheck)
@@ -1244,12 +1240,11 @@ theme_mbnma <- function(...) {
 #' @param x An object of class `"mb.rank"` generated by `rank.mbnma()`
 #' @param sucra A logical object to indicate whether Surface Under Cumulative Ranking Curve (SUCRA)
 #' values should be calculated and returned as a data frame. Areas calculated
-#' using \code{\link[rgeos]{readWKT}}.
+#' using trapezoid approach.
 #' @param ... Arguments to be sent to `ggplot::geom_line()`
-#' @inheritParams rank.mbnma
 #'
-#' @return Line plots showing the cumulative ranking probabilities for each agent/class and
-#' dose-response parameter in `x`. The object returned is a list which contains the plot
+#' @return Line plots showing the cumulative ranking probabilities for each agent/class for
+#' the ranked dose response paramtere in `x`. The object returned is a list which contains the plot
 #' (an object of `class(c("gg", "ggplot")`) and a data frame of SUCRA values
 #' if `sucra = TRUE`.
 #'
@@ -1260,43 +1255,52 @@ theme_mbnma <- function(...) {
 #'
 #' # Estimate rankings  from an Emax dose-response MBNMA
 #' emax <- mb.run(network, fun=temax())
-#' ranks <- rank(emax, params=c("emax", "et50", "auc"))
+#' ranks <- rank(emax, param=c("emax"))
 #'
 #' # Plot cumulative rankings for both dose-response parameters simultaneously
 #' # Note that SUCRA values are also returned
 #' cumrank(ranks)
 #' }
 #' @export
-cumrank <- function(x, params=NULL, sucra=TRUE, ...) {
+cumrank <- function(x, sucra=TRUE, ...) {
 
   # Run checks
   argcheck <- checkmate::makeAssertCollection()
   checkmate::assertClass(x, "mb.rank", add=argcheck)
-  checkmate::assertCharacter(params, null.ok=TRUE, add=argcheck)
   checkmate::assertLogical(sucra, null.ok=FALSE, add=argcheck)
   checkmate::reportAssertions(argcheck)
 
   output <- list()
 
-  if (is.null(params)) {
-    params <- names(x)
-  }
+  # if (is.null(params)) {
+  #   params <- names(x)
+  # }
+  params <- x$param
 
   df <- data.frame()
-  for (param in seq_along(params)) {
-    if (!params[param] %in% names(x)) {
-      stop(paste0(params[param], " is not a ranked parameter in x"))
-    }
 
-    cum.mat <- x[[params[param]]]$cum.matrix
-    treats <- colnames(cum.mat)
+  cum.mat <- x$cum.matrix
+  treats <- colnames(cum.mat)
 
-    melt <- reshape2::melt(cum.mat)
-    melt$param <- params[param]
+  melt <- reshape2::melt(cum.mat)
+  melt$param <- params
 
-    df <- rbind(df, melt)
+  df <- rbind(df, melt)
 
-  }
+  # for (param in seq_along(params)) {
+  #   if (!params[param] %in% x$param) {
+  #     stop(paste0(params[param], " is not a ranked parameter in x"))
+  #   }
+  #
+  #   cum.mat <- x[[params[param]]]$cum.matrix
+  #   treats <- colnames(cum.mat)
+  #
+  #   melt <- reshape2::melt(cum.mat)
+  #   melt$param <- params[param]
+  #
+  #   df <- rbind(df, melt)
+  #
+  # }
 
   df$Parameter <- factor(df$param)
 
