@@ -18,6 +18,8 @@
 #' identifier must also have the same class identifier.
 #' * `n` An optional column indicating the number of participants used to calculate the
 #' response at a given observation (required if modelling using Standardised Mean Differences)
+#' * `standsd` An optional column of numeric data indicating reference SDs used to standardise
+#' treatment effects when modelling using Standardised Mean Differences (SMD).
 #' @param reference A number or character (depending on the format of `treatment` within `data.ab`)
 #' indicating the reference treatment in the network (i.e. those for which estimated relative treatment
 #' effects estimated by the model will be compared to).
@@ -283,7 +285,7 @@ add_index <- function(data.ab, reference=1) {
     classes <- as.character(unique(classdata$class))
 
     # Recode classes
-    newdat$class <- as.numeric(factor(newdat$class, levels=classes))
+    outlist$data.ab$class <- as.numeric(factor(newdat$class, levels=classes))
 
     # Generate class key
     classkey <- unique(classdata)
@@ -353,7 +355,9 @@ add_index <- function(data.ab, reference=1) {
 #' jagsdat <- getjagsdata(painnet$data.ab, rho="dunif(0,1)", covstruct="AR1")
 #'
 #' @export
-getjagsdata <- function(data.ab, fun=NULL, class=FALSE, rho=NULL, covstruct="CS", link="identity", cfb=NULL) {
+getjagsdata <- function(data.ab, fun=NULL, class=FALSE,
+                        rho=NULL, covstruct="CS",
+                        link="identity", sdscale=FALSE, cfb=NULL) {
 
   # Run Checks
   argcheck <- checkmate::makeAssertCollection()
@@ -362,36 +366,32 @@ getjagsdata <- function(data.ab, fun=NULL, class=FALSE, rho=NULL, covstruct="CS"
   checkmate::assertChoice(covstruct, choices=c("varadj", "CS", "AR1"), null.ok=TRUE, add=argcheck)
   checkmate::assertClass(fun, "timefun", null.ok=TRUE, add=argcheck)
   checkmate::assertLogical(cfb, len=length(unique(data.ab$studyID)), null.ok=TRUE, add=argcheck)
+  checkmate::assertLogical(sdscale, len = 1, add=argcheck)
   checkmate::reportAssertions(argcheck)
 
   df <- data.ab
 
-  # dataset = factor indicating which data is required for the analysis (treatment univariate, treatment multivariate, class univariate, class multivariate)
-  # if (class==FALSE & is.null(rho)) {
-  #   dataset <- 1
-  # } else if (class==TRUE & is.null(rho)) {
-  #   dataset <- 2
-  # } else if (class==FALSE & !is.null(rho)) {
-  #   dataset <- 3
-  # } else if (class==TRUE & !is.null(rho)) {
-  #   dataset <- 4
-  # }
-
   varnames <- c("studyID", "y", "se", "treatment", "time", "arm", "fupcount")
 
-  if (link=="smd") {
-    varnames <- append(varnames, "n")
-
-    # Check all values of n are present
-    if (any(is.na(data.ab$n))) {
-      stop("Missing values in n - cannot use link='smd'")
-    }
-  }
-
   if (class==TRUE) {
     varnames <- append(varnames, "class")
   }
 
+  if (link=="smd") {
+    if (sdscale==TRUE) {
+      # Use refernce SD for standardising
+      varnames <- append(varnames, "standsd")
+    } else {
+      # Use pooled study-specific SD for standardising
+      varnames <- append(varnames, "n")
+
+      # Check all values of n are present
+      if (any(is.na(data.ab$n))) {
+        stop("Missing values in n - cannot estimate study-specific SDs")
+      }
+    }
+  }
+
   # Check correct variables are present
   if (!all(varnames %in% names(df))) {
     msg <- paste0("Variables are missing from dataset:\n",
@@ -473,6 +473,10 @@ getjagsdata <- function(data.ab, fun=NULL, class=FALSE, rho=NULL, covstruct="CS"
     datalist[["class"]] <- classcode
   }
 
+  if (sdscale==TRUE) {
+    datalist[["pool.sd"]] <- vector()
+  }
+
   # Generate empty spline matrix
   if (!is.null(fun)) {
     if (any(c("ns", "bs", "ls") %in% fun$name)) {
@@ -508,6 +512,11 @@ getjagsdata <- function(data.ab, fun=NULL, class=FALSE, rho=NULL, covstruct="CS"
   for (i in 1:max(as.numeric(df$studyID))) {
     datalist[["studyID"]] <- append(datalist[["studyID"]], df$studynam[as.numeric(df$studyID)==i][1])
 
+    if (sdscale==TRUE) {
+      datalist[["pool.sd"]] <- append(datalist[["pool.sd"]], df$standsd[as.numeric(df$studyID)==i &
+                                                                          df$arm==1 & df$fupcount==1])
+    }
+
     for (k in 1:max(df$arm[df$studyID==i])) {
 
       datalist[["treat"]][i,k] <- unique(df$treatment[as.numeric(df$studyID)==i &
@@ -576,8 +585,14 @@ getjagsdata <- function(data.ab, fun=NULL, class=FALSE, rho=NULL, covstruct="CS"
 #'
 #' @inheritParams mb.run
 #'
-#' @return A data frame in long format of responses at the latest time point in
-#'   each arm of each study.
+#' @return A list containing:
+#'
+#' * a data frame in long format of responses at the latest time point in
+#'   each arm of each study
+#' * a vector of studyIDs
+#' * a vector of treatment names
+#' * a vector of class names (if included in `network`)
+#' * a data frame of treatment -> class codings (if included in `network`)
 #'
 #' @examples
 #' # Using the alogliptin dataset
@@ -599,7 +614,18 @@ get.latest.time <- function(network) {
 
   df <- dplyr::arrange(df, studyID, arm, time)
 
-  return(df)
+  out <- list(
+    data.ab=df,
+    studyID=network$studyID,
+    treatments=network$treatments
+  )
+
+  if ("classes" %in% names(network)) {
+    out[["classes"]] <- network$classes
+    out[["classkey"]] <- network$classkey
+  }
+
+  return(out)
 }
 
 
@@ -614,14 +640,20 @@ get.latest.time <- function(network) {
 #'
 #' @inheritParams mb.run
 #'
-#' @return A data frame in long format of responses at the earliest time point in
-#'   each arm of each study.
+#' @return A list containing:
+#'
+#' * a data frame in long format of responses at the earliest time point in
+#'   each arm of each study
+#' * a vector of studyIDs
+#' * a vector of treatment names
+#' * a vector of class names (if included in `network`)
+#' * a data frame of treatment -> class codings (if included in `network`)
 #'
 #' @examples
 #' # Using the alogliptin dataset
 #' network <- mb.network(alog_pcfb)
 #'
-#' # Generate a data frame with only the earliest time point included in each study
+#' # Generate a data set with only the earliest time point included in each study
 #' get.earliest.time(network)
 #'
 #' @export
@@ -635,7 +667,18 @@ get.earliest.time <- function(network) {
 
   df <- dplyr::arrange(df, studyID, arm, time)
 
-  return(df)
+  out <- list(
+    data.ab=df,
+    studyID=network$studyID,
+    treatments=network$treatments
+  )
+
+  if ("classes" %in% names(network)) {
+    out[["classes"]] <- network$classes
+    out[["classkey"]] <- network$classkey
+  }
+
+  return(out)
 }
 
 
@@ -1030,6 +1073,7 @@ mb.make.contrast <- function(network, datatype=NULL, format="wide") {
 #' * Checks that class codes are consistent within each treatment
 #' * Checks that treatment codes are consistent across different time points within a study
 #' * Checks that studies have at least two arms (if `single.arm = FALSE`)
+#' * Checks that standsd values are consistent within a study
 #'
 #' @return An error or warnings if checks are not passed. Runs silently if checks are passed
 #'
@@ -1189,6 +1233,17 @@ mb.validate.data <- function(data.ab, single.arm=FALSE, CFB=TRUE) {
     }
   }
 
+  # Check that standardising SDs are consistent within each study
+  if ("standsd" %in% names(data.ab)) {
+    stansd.df <- data.ab %>% dplyr::ungroup(.) %>%
+      dplyr::select(studyID, standsd) %>%
+      unique(.)
+
+    if (nrow(stansd.df)!=length(unique(stansd.df$studyID))) {
+      stop("Standardising SDs in `data.ab$standsd` must be identical within each study")
+    }
+  }
+
 }
 
 
@@ -1344,16 +1399,17 @@ genspline <- function(x, spline="bs", knots=1, degree=1, max.time=max(x), bounda
 #' network <- mb.network(alog_pcfb)
 #'
 #' # Construct a dataset with the latest time point in each study
-#' data.ab <- get.latest.time(network)
+#' data.ab <- get.latest.time(network)$data.ab
 #' getnmadata(data.ab)
 #'
 #' @export
-getnmadata <- function(data.ab, link="identity") {
+getnmadata <- function(data.ab, link="identity", sdscale=FALSE) {
 
   # Run Checks
   argcheck <- checkmate::makeAssertCollection()
   checkmate::assertDataFrame(data.ab, add=argcheck)
   checkmate::assertChoice(link, choices = c("identity", "smd", "log"), null.ok = FALSE, add=argcheck)
+  checkmate::assertLogical(sdscale, len = 1, add=argcheck)
   checkmate::reportAssertions(argcheck)
 
   df <- data.ab
@@ -1361,7 +1417,11 @@ getnmadata <- function(data.ab, link="identity") {
   varnames <- c("y", "se", "treatment", "arm")
 
   if (link=="smd") {
-    varnames <- append(varnames, "n")
+    if (sdscale==TRUE) {
+      varnames <- append(varnames, "pool.sd")
+    } else {
+      varnames <- append(varnames, "n")
+    }
   }
 
   # Check correct variables are present
@@ -1381,7 +1441,9 @@ getnmadata <- function(data.ab, link="identity") {
   # Prepare list variables at each level
   datavars <- c("y", "se", "treat")
   if (link=="smd") {
-    datavars <- append(datavars, "n")
+    if (sdscale==FALSE) {
+      datavars <- append(datavars, "n")
+    }
   }
 
   # Create a separate object for each datavars
@@ -1404,10 +1466,18 @@ getnmadata <- function(data.ab, link="identity") {
     datalist[[datavars[i]]] <- get(datavars[i])
   }
 
+  if (sdscale==TRUE) {
+    datalist[["pool.sd"]] <- vector()
+  }
+
   # Add data to datalist elements
   for (i in 1:max(as.numeric(df$studyID))) {
     datalist[["studyID"]] <- append(datalist[["studyID"]], df$studynam[as.numeric(df$studyID)==i][1])
 
+    if (sdscale==TRUE) {
+      datalist[["pool.sd"]] <- append(datalist[["pool.sd"]], unique(df$standsd[as.numeric(df$studyID)==i]))
+    }
+
     for (k in 1:max(df$arm[df$studyID==i])) {
 
       datalist[["treat"]][i,k] <- unique(df$treatment[as.numeric(df$studyID)==i &
