@@ -1,6 +1,6 @@
 testthat::context("Testing prepare.functions")
 
-datalist <- list(osteopain, copd, goutSUA_CFBcomb)
+datalist <- list(osteopain, copd, goutSUA_CFBcomb, hyalarthritis, diabetes, alog_pcfb)
 
 ################### Testing add_index ################
 
@@ -9,11 +9,16 @@ testthat::test_that("add_index functions correctly", {
     testthat::expect_equal(is.character(add_index(datalist[[i]])[["treatments"]]), TRUE)
     testthat::expect_equal(is.numeric(add_index(datalist[[i]])[["data.ab"]]$treatment), TRUE)
 
-    testthat::expect_error(mb.network(datalist[[i]], ref="test"))
+    if (is.numeric(datalist[[i]]$treatment)) {
+      testthat::expect_error(mb.network(datalist[[i]], ref="test"), "treatment must correspond to format of treatments")
+    } else {
+      testthat::expect_error(mb.network(datalist[[i]], ref="test"), "treatment specified is not a treatment")
+      testthat::expect_message(mb.network(datalist[[i]], ref=1), "Reference treatment is `")
+    }
 
-    testthat::expect_error(mb.network(datalist[[i]], ref=40))
-    testthat::expect_message(mb.network(datalist[[i]], ref=1))
-    testthat::expect_message(mb.network(datalist[[i]], ref=NULL))
+
+    testthat::expect_error(mb.network(datalist[[i]], ref=40), "treatment specified is not a treatment")
+    testthat::expect_message(mb.network(datalist[[i]], ref=NULL), "treatment has automatically been set")
 
     testthat::expect_error(mb.network(datalist[[i]], ref="Notarealtreatment"))
   }
@@ -125,6 +130,12 @@ test_that("mb.network functions correctly", {
 
   expect_silent(mb.network(obesityBW_CFB, reference = "orli",
                            cfb=rep(FALSE, dplyr::n_distinct(obesityBW_CFB$studyID))))
+
+
+  for (i in seq_along(datalist)) {
+    expect_error(mb.network(datalist[[i]]),NA)
+    expect_warning(mb.network(datalist[[i]]),NA)
+  }
 })
 
 
@@ -185,23 +196,23 @@ test_that("genspline functions correctly", {
   expect_error(genspline(x, spline="ns", knots = c(1,4)), "probs")
   expect_error(genspline(x, spline="ns", knots = 5), "unlikely to be able to support it")
 
-  # Restricted cubic splines
-  rcs <- genspline(x, spline="rcs", knots = 3)
-  expect_equal(c("matrix", "array"), class(rcs))
-  expect_equal(ncol(rcs), 2)
-
-  rcs <- genspline(x, spline="rcs", knots = 3, degree=2)
-  expect_equal(ncol(rcs), 2) # degree doesn't matter for ns
-
-  rcs <- genspline(x, spline="rcs", knots = 4)
-  expect_equal(ncol(rcs), 3)
-
-  rcs <- genspline(x, spline="rcs", knots = c(0.1,0.8,0.9))
-  expect_equal(ncol(rcs), 2)
-
-  expect_error(genspline(x, spline="rcs", knots = 1, degree=1))
-  expect_error(genspline(x, spline="rcs", knots = -1))
-  expect_error(genspline(x, spline="rcs", knots = c(1,4,7)), "probs")
-  expect_error(genspline(x, spline="rcs", knots = 7), "unlikely to be able to support it")
+  # # Restricted cubic splines
+  # rcs <- genspline(x, spline="rcs", knots = 3)
+  # expect_equal(c("matrix", "array"), class(rcs))
+  # expect_equal(ncol(rcs), 2)
+  #
+  # rcs <- genspline(x, spline="rcs", knots = 3, degree=2)
+  # expect_equal(ncol(rcs), 2) # degree doesn't matter for ns
+  #
+  # rcs <- genspline(x, spline="rcs", knots = 4)
+  # expect_equal(ncol(rcs), 3)
+  #
+  # rcs <- genspline(x, spline="rcs", knots = c(0.1,0.8,0.9))
+  # expect_equal(ncol(rcs), 2)
+  #
+  # expect_error(genspline(x, spline="rcs", knots = 1, degree=1))
+  # expect_error(genspline(x, spline="rcs", knots = -1))
+  # expect_error(genspline(x, spline="rcs", knots = c(1,4,7)), "probs")
+  # expect_error(genspline(x, spline="rcs", knots = 7), "unlikely to be able to support it")
 
 })
